==> haskell-mustache-2.3.0-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-8QXybOhUuky4ZxPxq4M4qF
key: mustache-2.3.0-8QXybOhUuky4ZxPxq4M4qF
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: 0fc68e6804eb5c685c13888dfa2f225a
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-8QXybOhUuky4ZxPxq4M4qF
depends:
    base-4.11.1.0 text-1.2.3.0 aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    bytestring-0.10.8.2 filepath-1.4.2 parsec-3.1.13.0 mtl-2.2.2
    either-5.0.1-8V61GP066b4CftmZrhKbyV
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq directory-1.3.1.5
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul containers-0.5.11.0
    template-haskell-2.13.0.0 th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             either-5.0.1-8V61GP066b4CftmZrhKbyV=f847b993d0d1a1372490beb740058531
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa=8e1228f791eed129f803114371365300
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.3.0-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mustache
version: 2.3.0
id: mustache-2.3.0-K5mkBHxmdBs2AIqjLbwGpj
key: mustache-2.3.0-K5mkBHxmdBs2AIqjLbwGpj
license: BSD-3-Clause
copyright: (c) 2015,
           2016 Justus Adam
maintainer: dev@justus.science
author: Justus Adam
homepage: https://github.com/JustusAdam/mustache
synopsis: A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.
    .
    Implements the mustache spec version 1.1.3.
    .
    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.
category: Development
abi: b3d68dd1e189d3eb86e2665ce66902f1
exposed: True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types
hidden-modules: Text.Mustache.Internal Text.Mustache.Internal.Types
                Paths_mustache
import-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/mustache-2.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/mustache-2.3.0
hs-libraries: HSmustache-2.3.0-K5mkBHxmdBs2AIqjLbwGpj
depends:
    base-4.11.1.0 text-1.2.3.0 aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    bytestring-0.10.8.2 filepath-1.4.2 parsec-3.1.13.0 mtl-2.2.2
    either-5.0.1-8V61GP066b4CftmZrhKbyV
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq directory-1.3.1.5
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul containers-0.5.11.0
    template-haskell-2.13.0.0 th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             either-5.0.1-8V61GP066b4CftmZrhKbyV=f847b993d0d1a1372490beb740058531
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=dc9b33f81f401bd0ab050d9bb851ae71
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa=8e1228f791eed129f803114371365300
haddock-interfaces: /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html: /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
